#include <iomanip>
#include <iostream>
#include <map>
#include <utility>
#include <vector>
 
class BigInt {
   public:
    static const long long BASE = 1000000000;  // Base 10^9
    static const int BASE_DIGITS = 9;    // Number of digits in each element
 
    std::vector<long long> digits;
 
    BigInt() {}
 
    BigInt(unsigned long long num) {
        while (num > 0) {
            digits.push_back(num % BASE);
            num /= BASE;
        }
    }
 
    BigInt(const std::vector<long long>& nums) : digits(nums) {}
 
    bool operator<(const BigInt& other) const {
        if (digits.size() < other.digits.size()) {
            return true;
        } else if (digits.size() > other.digits.size()) {
            return false;
        }
 
        for (int i = digits.size() - 1; i >= 0; i--) {
            if (digits[i] < other.digits[i]) {
                return true;
            } else if (digits[i] > other.digits[i]) {
                return false;
            }
        }
 
        return false;
    }
 
    BigInt operator+(const BigInt& other) const {
        int carry = 0;
        std::vector<long long> result;
 
        int i = 0;
        while (i < digits.size() || i < other.digits.size() || carry != 0) {
            int sum = carry;
            if (i < digits.size()) {
                sum += digits[i];
            }
            if (i < other.digits.size()) {
                sum += other.digits[i];
            }
 
            result.push_back(sum % BASE);
            carry = sum / BASE;
            i++;
        }
 
        return BigInt(result);
    }

    BigInt operator-(const BigInt& other) const {
        int borrow = 0;
        std::vector<long long> result;

        int i = 0;
        while (i < digits.size()) {
            int diff = digits[i] - borrow;
            if (i < other.digits.size()) {
                diff -= other.digits[i];
            }

            if (diff < 0) {
                diff += BASE;
                borrow = 1;
            } else {
                borrow = 0;
            }

            result.push_back(diff);
            i++;
        }

        // Remove leading zeros if any
        while (result.size() > 1 && result.back() == 0) {
            result.pop_back();
        }

        return BigInt(result);
    }
 
    BigInt operator*(const BigInt& other) const {
        std::vector<long long> result(digits.size() + other.digits.size(), 0);
 
        for (int i = 0; i < digits.size(); i++) {
            long long carry = 0;
            for (int j = 0; j < other.digits.size(); j++) {
                long long product =
                    digits[i] * other.digits[j] + carry + result[i + j];
                result[i + j] = product % BASE;
                carry = product / BASE;
            }
            if (carry > 0) {
                result[i + other.digits.size()] += carry;
            }
        }
 
        // Remove leading zeroes
        while (result.size() > 1 && result.back() == 0) {
            result.pop_back();
        }
 
        return BigInt(result);
    }
 
    unsigned long long toULL() const {
        unsigned long long num = 0;
        unsigned long long powBase = 1;
        for (int i = 0; i < digits.size(); i++) {
            num += digits[i] * powBase;
            powBase *= BASE;
        }
        return num;
    }
};
 
void printBigInt(const BigInt& num) {
    std::cout << num.digits.back();
    for (int i = num.digits.size() - 2; i >= 0; i--) {
        std::cout << std::setfill('0') << std::setw(BigInt::BASE_DIGITS)
                  << num.digits[i];
    }
    std::cout << "\n";
}
 
int main() {
    int n;
    std::cin >> n;
    std::map<std::pair<BigInt, BigInt>, BigInt> dp;
    dp[{BigInt(0), BigInt(1)}] = BigInt(1);
 
    for (int l = 0; l < n; l++) {
        std::map<std::pair<BigInt, BigInt>, BigInt> ndp;
        for (const auto& entry : dp) {
            BigInt s = entry.first.first;
            BigInt p = entry.first.second;
            for (int di = 1; di < 10; di++) {
                BigInt newS = s + BigInt(di);
                BigInt newP = p * BigInt(di);
                std::pair<BigInt, BigInt> newpair = {newS, newP};
                ndp[newpair] = ndp[newpair] + entry.second;
            }
        }
        dp = ndp;
    }
 
    BigInt ans = BigInt(0);
        for (auto [p, cnt]: dp) {
        BigInt two = cnt;

        if (dp.count({p.first - BigInt(1), p.second})) {
            two = two + dp[{p.first - BigInt(1), p.second}]; 
        }
        if (dp.count({p.first + BigInt(1), p.second})) {
            two = two + dp[{p.first + BigInt(1), p.second}]; 
        }
        ans = ans + cnt * two;
    }

 
    printBigInt(ans);
 
    return 0;
}
